<?php
/**
 * @file
 * Admin items for the blajax module.
 */

/* -------------------------------------------------------------------------- */

/**
 * Main administration form.
 */
function blajax_admin_settings_form(&$form_state) {
  $form = array(
    'links' => array(
      '#type' => 'fieldset',
      '#title' => t('Link settings'),
      '#collapsible' => FALSE,
      'blajax_link_no_icons' => array(
        '#type' => 'checkbox',
        '#title' => t('Do not use icons'),
        '#description' => t('No icons will be used to illustrate the toolbar functions'),
        '#default_value' => variable_get('blajax_link_no_icons', FALSE),
      ),
    ),
    'toolbar' => array(
      '#type' => 'fieldset',
      '#title' => t('Toolbar settings'),
      'blajax_toolbar_paths' => array(
        '#type' => 'fieldset',
        '#title' => t('General Include/exclude options'),
        '#description' => t('You may specify paths to determine that toolbars are added only on/not added on certain pages.'),
        'blajax_paths_option' => array(
          '#type' => 'radios',
          '#title' => t('Include/exclude options'),
          '#default_value' => variable_get(
            'blajax_paths_option',
            0
          ),
          '#options' => array(
            0 => t('Show on every page except the listed pages.'),
            1 => t('Show on only the listed pages.'),
          ),
        ),
        'blajax_paths_list' => array(
          '#type' => 'textarea',
          '#title' => t('Pages'),
          '#rows' => 5,
          '#default_value' => variable_get(
            'blajax_paths_list',
            ''
          ),
          '#description' => t(
            "Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.",
            array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>')
          ),
        ),
      ),
      'blajax_toolbar_js' => array(
        '#type' => 'fieldset',
        '#title' => t('Javascript and effects'),
        'blajax_enable_js' => array(
          '#type' => 'checkbox',
          '#title' => t('Enable Javascript and effects'),
          '#size' => 3,
          '#description' => t('Disable this option if you do not want to make use of Javascript effects and AJAX behavior at all.'),
          '#default_value' => variable_get(
            'blajax_enable_js',
            1
          ),
        ),
        'blajax_toolbar_paths_js' => array(
          '#type' => 'fieldset',
          '#title' => t('Javascript Include/exclude options'),
          '#collapsible' => TRUE,
          '#collapsed' => TRUE,
          '#description' => t('You may specify paths where toolbars will or not use Javascript.'),
          'blajax_paths_js_option' => array(
            '#type' => 'radios',
            '#title' => t('Include/exclude options'),
            '#default_value' => variable_get(
              'blajax_paths_js_option',
              0
            ),
            '#options' => array(
              0 => t('Show on every page except the listed pages.'),
              1 => t('Show on only the listed pages.'),
            ),
          ),
          'blajax_paths_js_list' => array(
            '#type' => 'textarea',
            '#title' => t('Pages'),
            '#rows' => 5,
            '#default_value' => variable_get(
              'blajax_paths_js_list',
              ''
            ),
            '#description' => t(
              "Enter one page per line as Drupal paths. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.",
              array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>')
            ),
          ),
        ),
        'blajax_toolbar_position' => array(
          '#type' => 'radios',
          '#title' => t('Toolbar position'),
          '#description' => ("Where to place each block's toolbar if Javascript is enabled"),
          '#default_value' => variable_get(
            'blajax_toolbar_position',
            0
          ),
          '#options' => array(
            1 => t('top'),
            0 => t('bottom'),
          ),
        ),
        'blajax_toolbar_opacity' => array(
          '#type' => 'textfield',
          '#title' => t('Transparency'),
          '#size' => 3,
          '#field_suffix' => '%',
          '#description' => t("With Javascript enabled, the block's toolbars can be transparent unless being hovered. All non-numeric values will be ignored."),
          '#default_value' => variable_get(
            'blajax_toolbar_opacity',
            50
          ),
        ),
        'blajax_toolbar_effect' => array(
          '#type' => 'radios',
          '#title' => t('Show/hide'),
          '#description' => t('With Javascript enabled, a toolbar can remain invisible unless a block is being hovered.'),
          '#default_value' => variable_get(
            'blajax_toolbar_effect',
            0
          ),
          '#options' => array(
            0 => t('Always show'),
            1 => t('Slide in/out'),
            2 => t('Fade in/out'),
          ),
        ),
        'blajax_block_effect' => array(
          '#type' => 'checkbox',
          '#title' => t('Use animations on block actions'),
          '#default_value' => variable_get(
            'blajax_block_effect',
            1
          ),
        ),
      ),
    ),
  );
  $tooltips = array(
    'hide' => 'Hide this block',
    'minimize' => 'Minimize this block',
    'maximize' => 'Restore this block',
    'refresh' => 'Reload the content of this block',
    'edit' => "Configure this block's settings",
  );
  foreach ($tooltips as $type => $tip) {
    $form['links'][$type] = array(
      '#type' => 'fieldset',
      '#title' => t(
        '!linktype link',
        array('!linktype' => t(drupal_ucfirst($type)))
      ),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#description' => t(
        'Settings for the %linktype link',
        array('%linktype' => t(drupal_ucfirst($type)))
      ),
      'blajax_link_' . $type . '_text' => array(
        '#type' => 'textfield',
        '#title' => t('Link label'),
        '#default_value' => variable_get(
          'blajax_link_' . $type . '_text',
          t(drupal_ucfirst($type))
        ),
        '#size' => 50,
        '#maxlength' => 50,
        '#required' => TRUE,
        '#description' => t('Link text to be displayed unless using an icon'),
      ),
      'blajax_link_' . $type . '_title' => array(
        '#type' => 'textfield',
        '#title' => t('Link tooltip'),
        '#default_value' => variable_get(
          'blajax_link_' . $type . '_title',
          t($tip)
        ),
        '#size' => 50,
        '#maxlength' => 150,
        '#required' => TRUE,
        '#description' => t('Tooltip to be displayed when hovering the link'),
      ),
    );
  }
  return system_settings_form($form);
}

